StdHeader

Enum StdHeader 

pub enum StdHeader {
Show 24 variants Assert, Ctype, Errno, Float, Limits, Locale, Math, Setjmp, Signal, Stdarg, Stdbool, Stddef, Stdint, Stdio, Stdlib, String, Time, Unistd, Fcntl, Dirent, SysTypes, SysStat, SysMman, Wchar,
}
ISO C99 7 Standard Library Headers + POSIX extensions

Variants



Assert



Ctype



Errno



Float



Limits



Locale



Math



Setjmp



Signal



Stdarg



Stdbool



Stddef



Stdint



Stdio



Stdlib



String



Time



Unistd



Fcntl



Dirent



SysTypes



SysStat



SysMman



Wchar

Implementations

Source

impl StdHeader

pub fn from_filename(filename: &str) -> Option<Self>

Parse header name from #include filename

Examples
use decy_stdlib::StdHeader;
assert_eq!(StdHeader::from_filename("string.h"), Some(StdHeader::String));
assert_eq!(StdHeader::from_filename("stdio.h"), Some(StdHeader::Stdio));
assert_eq!(StdHeader::from_filename("unknown.h"), None);